use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007006
use Test::Spelling 0.17;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
Dagfinn
Doran
Etheridge
Florian
Graham
Gregory
Ilmari
Inc
Infinity
Interactive
Karen
Knop
LoadableClass
Mannsåker
MooseX
Oschwald
Ragwitz
Tomas
Types
bobtfish
ether
goschwald
haarg
ilmari
irc
lib
rafl
sromanov
Романов
Сергей
